@@ -3,9 +3,10 @@ from .angle_coder import CSLCoder
 from .delta_midpointoffset_rbbox_coder import MidpointOffsetCoder
 from .delta_xywha_hbbox_coder import DeltaXYWHAHBBoxCoder
 from .delta_xywha_rbbox_coder import DeltaXYWHAOBBoxCoder
+from .distance_angle_point_coder import DistanceAnglePointCoder
 from .gliding_vertex_coder import GVFixCoder, GVRatioCoder
 
 __all__ = [
     'DeltaXYWHAOBBoxCoder', 'DeltaXYWHAHBBoxCoder', 'MidpointOffsetCoder',
-    'GVFixCoder', 'GVRatioCoder', 'CSLCoder'
+    'GVFixCoder', 'GVRatioCoder', 'CSLCoder', 'DistanceAnglePointCoder'
 ]
